.. imprint: a program for creating documents from data and content templates

.. Copyright (C) 2019  Joseph R. Fox-Rabinovitz <jfoxrabinovitz at gmail dot com>

.. This program is free software: you can redistribute it and/or modify
.. it under the terms of the GNU Affero General Public License as
.. published by the Free Software Foundation, either version 3 of the
.. License, or (at your option) any later version.

.. This program is distributed in the hope that it will be useful,
.. but WITHOUT ANY WARRANTY; without even the implied warranty of
.. MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
.. GNU Affero General Public License for more details.

.. Author: Joseph Fox-Rabinovitz <jfoxrabinovitz at gmail dot com>
.. Version: 13 Apr 2019: Initial Coding


.. _tutorials:

=========
Tutorials
=========

The pages in the tutorials section show step-by-step instructions on how to get
Imprint up and running. They cover virtually every aspect of the program from
the point of view of various types of users. For a quick reference, consult the
:doc:`/reference/reference` documents.

For the basic user, there is the :doc:`getting_started` page. It is the
recommended next step for all first-time users. Once you have mastered that,
:doc:`basic_tutorial` will show you a more complete picture.

For the more advanced customization techniques, start with
:doc:`additional_topics_1`, :doc:`additional_topics_2`, and
:doc:`styles_tutorial`. More advanced subjects, with coding involved, are
explored in the :doc:`plugin_tutorial` and :doc:`tag_tutorial` tutorials.

Developers can probably jump right into the :doc:`/reference/reference`
section with the :doc:`/reference/plugin_api` and the
:doc:`Tag API </reference/tag_api>`.

If you are unsure where to go next, the :doc:`Main Page </index>` is
always a good place to start browsing through all of the available topics.

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   :name: tutorials-toc

   getting_started
   basic_tutorial
   additional_topics_1
   additional_topics_2
   styles_tutorial
   plugin_tutorial
   tag_tutorial


.. _tutorials-demos:

-----
Demos
-----

The tutorials in this documentation rely on a number of small demo projects to
illustrate the features of Imprint. The projects are available for download as
zip files so that the reader can follow along in the tutorial and experiment on
their own. The following is a list of the available demo projects:

- :download:`HelloWorld </demos/HelloWorld.zip>` for :ref:`t_start`
- :download:`CandleFlame </demos/CandleFlame.zip>` for :ref:`t_basic`
- :download:`Games </demos/Games.zip>` for :ref:`t_additional_1`
- :download:`Invoice </demos/Invoice.zip>` for :ref:`t_additional_2`
- :download:`Snippets </demos/Snippets.zip>` for :ref:`t_styles`
- . . . for :ref:`t_plugin`
- . . . for :ref:`t_tag`
- :download:`PathologicalCases </demos/PathologicalCases.zip>` for testing
  purposes
